import { cut } from '@node-rs/jieba';

function segmentParagraphs(text) {
  return text.split(/[\f\n\r\t\v]+/);
}

function segmentSentences(text, options) {
  switch (options.lang) {
    case "zh":
      return text.match(/[^。？！；]+[。？！；]*[\p{P}]*/g);
    default:
      return text.match(/[^.?!;]+[.?!;]*([\x20]*)/g);
  }
}

function segmentPhrases(text, options) {
  switch (options.lang) {
    case "zh":
      return text.match(/[^，。？！；]+[。？！；]*[\p{P}]*/g);
    default:
      return text.match(/[^,.?!;]+[.?!;]*([\x20]*)/g);
  }
}

function segmentWords(text, options) {
  switch (options.lang) {
    case "zh":
      return cut(text, true);
    default:
      return text.split(/(\x20|[.?!;]+\x20)/g);
  }
}

function createSegmentation(text, options) {
  const { lang } = options;
  switch (options.segmentation) {
    case "paragraphs":
      return segmentParagraphs(text);
    case "sentences":
      return segmentSentences(text, {
        lang
      });
    case "phrases":
      return segmentPhrases(text, {
        lang
      });
    case "words":
      return segmentWords(text, {
        lang
      });
  }
}

export { createSegmentation, segmentParagraphs, segmentPhrases, segmentSentences, segmentWords };
